package org.jeecg.modules.bytedance.advertise.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.bytedance.advertise.dockapi.MarketingService;
import org.jeecg.modules.bytedance.common.entity.CtopOauthToken;
import org.jeecg.modules.bytedance.common.service.ICtopOauthTokenService;
import org.jeecg.modules.bytedance.common.service.IMaterialInfoService;
import org.jeecg.modules.bytedance.common.utils.Check;
import org.jeecg.modules.bytedance.report.service.IBytedanceAdvertiserHourlyReportService;
import org.jeecg.modules.bytedance.report.service.IBytedancePlanHourlyReportService;
import org.jeecg.modules.bytedance.report.service.IBytedanceReportMaterialDailyService;
import org.jeecg.modules.system.service.ISysRoleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.*;

/**
 * 投放数据
 * @author jeecg-boot
 * @date   2021-05-18
 * @version V1.0
 */
@RestController
@RequestMapping("/advertiser/bytedanceReportController")
@Api(tags="投放数据")
@Slf4j
public class BytedanceReportController {
	@Autowired
	private IBytedanceAdvertiserHourlyReportService bytedanceAdvertiserHourlyReportService;

	@Autowired
	private IBytedancePlanHourlyReportService bytedancePlanHourlyReportService;

	@Autowired
	private IBytedanceReportMaterialDailyService bytedanceReportMaterialDailyService;

	@Autowired
	private ISysRoleService sysRoleService;

	@Autowired
	private MarketingService marketingService;

	@Autowired
	private ICtopOauthTokenService tokenService;




	@ApiOperation(value="投放数据-获取当前用户花费最高的的账户", notes="投放数据-获取当前用户花费最高的的账户")
	@GetMapping(value = "/initAccountIdAndTime")
	public Result initAccountIdAndTime(@RequestParam("userId") String userId,
										 @RequestParam(value = "type",defaultValue = "bytedance") String type) {
		try {
			//查询用户角色
			String roleCode = sysRoleService.getRoleCodeByUserId(userId);
			if (Check.isNull(roleCode)){
				return Result.errorMsg("请输入正确的用户id。");
			}
			//角色为 管理员 || 销售 || 媒介 查询全部
			if ("admin".equals(roleCode) || roleCode.contains("sale") || "meidaManager".equals(roleCode)) {
				userId = null;
			}
			return bytedanceAdvertiserHourlyReportService.initAccountIdAndTime(userId,type);
		}catch (Exception e){
			log.error("投放数据-获取当前用户花费最高的的账户异常",e);
			return Result.error("请求失败，请联系开发人员!");
		}
	}





	@ApiOperation(value="投放数据-获取花费和同比", notes="投放数据-获取花费和同比")
	@GetMapping(value = "/getReportYearOnYearCost")
	public Result getReportYearOnYearCost(@RequestParam("accountId") String accountId,
										 @RequestParam("startTime") String startTime,
										 @RequestParam("endTime") String endTime) {
		try {
			return bytedanceAdvertiserHourlyReportService.getReportYearOnYearCost(accountId,startTime,endTime);
		}catch (Exception e){
			log.error("投放数据-获取花费和环比异常",e);
			return Result.error("请求失败，请联系开发人员!");
		}
	}




	@ApiOperation(value="投放数据-查询账户余额", notes="投放数据-查询账户余额")
	@GetMapping(value = "/getAccountCost")
	public Result getAccountCost(@RequestParam("accountId") String accountId) {
		try {
			return bytedanceAdvertiserHourlyReportService.getAccountCost(accountId);
		}catch (Exception e){
			log.error("投放数据-获取花费和环比异常",e);
			return Result.error("请求失败，请联系开发人员!");
		}
	}


	@ApiOperation(value="投放数据-查询计划数据", notes="投放数据-查询计划数据")
	@GetMapping(value = "/getReportPlanCost")
	public Result getReportPlanCost(@RequestParam("accountId") String accountId,
									@RequestParam("startTime") String startTime,
									@RequestParam("endTime") String endTime,
									@RequestParam(value = "pageNum",defaultValue = "1") Integer pageNum,
									@RequestParam(value = "pageSize",defaultValue = "10") Integer pageSize) {
		try {
			return bytedanceAdvertiserHourlyReportService.getReportPlanCost(accountId,startTime,endTime,pageNum,pageSize);
		}catch (Exception e){
			log.error("投放数据-获取花费和环比异常",e);
			return Result.error("请求失败，请联系开发人员!");
		}
	}


	@ApiOperation(value="投放数据-更新计划出价", notes="投放数据-更新计划出价")
	@GetMapping(value = "/updateADBid")
	public Result updateADBid(@RequestParam("accountId") String accountId,
									@RequestParam("adId") String adId,
									@RequestParam("bid") BigDecimal bid) {
		try {
			CtopOauthToken token = tokenService.getOauthTokenByAccountId(accountId);
			List<Map<String, Object>> listMap = new ArrayList<>();
			Map<String, Object> map = new HashMap<>();
			map.put("ad_id",adId);
			map.put("bid",bid);
			listMap.add(map);
			return marketingService.updatePlanBid(token,accountId,listMap);
		}catch (Exception e){
			log.error("投放数据-获取花费和环比异常",e);
			return Result.error("请求失败，请联系开发人员!");
		}
	}













}
